==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/vo/InspectionVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 迎检登记-表头
 *
 * @author generator
 *
 */
public class InspectionVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pkOrg; // 组织
    private Long pkDept; // 部门
    private String approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private Long pkBilltype; // 单据类型
    private Integer billState; // 单据状态
    private Date ts; // 时间戳
    private String vbusitype; // 业务类型
    private String pkGroup; // 集团
    private String vbillcode; // 单据编号
    private String dbilldate; // 单据日期
    private String vmemo; // 备注
    private Long pkFqr; // 发起人
    private Long pkProject; // 报建立项
    private String pkContract; // 报建合同
    private Long pkPmproject; // 施工项目立项
    private Long pkPmprojectJlb; // 项目经理部
    private String yjTime; // 迎检时间
    private String vdef1; //
    private String vdef10; //
    private String vdef2; //
    private String vdef3; //
    private String vdef4; //
    private String vdef5; //
    private String vdef6; //
    private String vdef7; //
    private String vdef8; //
    private String vdef9; //

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }
    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDept() {
        return pkDept;
    }
    @ReferDeserialTransfer
    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    @ReferSerialTransfer(referCode = "billType")
    public Long getPkBilltype() {
        return pkBilltype;
    }
    @ReferDeserialTransfer
    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkFqr() {
        return pkFqr;
    }
    @ReferDeserialTransfer
    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    @ReferSerialTransfer(referCode = "market-project")
    public Long getPkProject() {
        return pkProject;
    }
    @ReferDeserialTransfer
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }
    @ReferSerialTransfer(referCode = "market-project")
    public Long getPkPmproject() {
        return pkPmproject;
    }
    @ReferDeserialTransfer
    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }
    @ReferDeserialTransfer
    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getYjTime() {
        return yjTime;
    }

    public void setYjTime(String yjTime) {
        this.yjTime = yjTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

}

==> ejc-credentials-impl-3.0.0-20220614.031901-51-sources.jar: com/ejianc/certify/vo/InspectionVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 迎检登记-表头
 *
 * @author generator
 *
 */
public class InspectionVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pkOrg; // 组织
    private Long pkDept; // 部门
    private String approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private Long pkBilltype; // 单据类型
    private Integer billState; // 单据状态
    private Date ts; // 时间戳
    private String vbusitype; // 业务类型
    private String pkGroup; // 集团
    private String vbillcode; // 单据编号
    private String dbilldate; // 单据日期
    private String vmemo; // 备注
    private Long pkFqr; // 发起人
    private Long pkProject; // 报建立项
    private String pkContract; // 报建合同
    private Long pkPmproject; // 施工项目立项
    private Long pkPmprojectJlb; // 项目经理部
    private String yjTime; // 迎检时间
    private String vdef1; //
    private String vdef10; //
    private String vdef2; //
    private String vdef3; //
    private String vdef4; //
    private String vdef5; //
    private String vdef6; //
    private String vdef7; //
    private String vdef8; //
    private String vdef9; //

    private List<InspectionBVO> inspectionBList = new ArrayList<>();

    public List<InspectionBVO> getInspectionBList() {
        return inspectionBList;
    }

    public void setInspectionBList(List<InspectionBVO> inspectionBList) {
        this.inspectionBList = inspectionBList;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }
    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDept() {
        return pkDept;
    }
    @ReferDeserialTransfer
    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    @ReferSerialTransfer(referCode = "billType")
    public Long getPkBilltype() {
        return pkBilltype;
    }
    @ReferDeserialTransfer
    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkFqr() {
        return pkFqr;
    }
    @ReferDeserialTransfer
    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    @ReferSerialTransfer(referCode = "market-project")
    public Long getPkProject() {
        return pkProject;
    }
    @ReferDeserialTransfer
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }
    @ReferSerialTransfer(referCode = "market-project")
    public Long getPkPmproject() {
        return pkPmproject;
    }
    @ReferDeserialTransfer
    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }
    @ReferDeserialTransfer
    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getYjTime() {
        return yjTime;
    }

    public void setYjTime(String yjTime) {
        this.yjTime = yjTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

}
